@@ -4,7 +4,12 @@ import typing
 import urllib.parse
 
 from .models import BaseGWDGUser, ChangeTemplate, CreateTemplate, IDMRequest
-from .util import AlreadyDeletedError, BadJsonError, IDMRequestError
+from .util import (
+    AlreadyDeletedError,
+    BadJsonError,
+    IDMRequestError,
+    UnexpectedJsonError,
+)
 
 if typing.TYPE_CHECKING:
     from requests import Response
@@ -45,7 +50,10 @@ class Benutzerverwaltung(IDMRequest):
             json_resp = json.loads(resp.text)
         except json.decoder.JSONDecodeError:
             raise BadJsonError(resp.text)
-        return [self.user_class.from_json(obj) for obj in json_resp["Objects"]]
+        try:
+            return [self.user_class.from_json(obj) for obj in json_resp["Objects"]]
+        except TypeError as e:
+            raise UnexpectedJsonError(str(e))
 
     def update_user(
         self, user: ChangeTemplate, update_dict: dict[str, str | list[str]]
